import { utils, BytesLike, BigNumberish, BaseContract, Signer, Overrides, ContractTransaction, CallOverrides, BigNumber, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

declare namespace ThirdwebContract {
    type ThirdwebInfoStruct = {
        publishMetadataUri: string;
        contractURI: string;
    };
    type ThirdwebInfoStructOutput = [string, string] & {
        publishMetadataUri: string;
        contractURI: string;
    };
}
interface IByocFactoryInterface extends utils.Interface {
    contractName: string | "IByocFactory";
    functions: {
        "deployInstance(address,bytes,bytes,bytes32,uint256,(string,string))": FunctionFragment;
        "deployInstanceProxy(address,address,bytes,bytes32,uint256,(string,string))": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "deployInstance", values: [
        string,
        BytesLike,
        BytesLike,
        BytesLike,
        BigNumberish,
        ThirdwebContract.ThirdwebInfoStruct
    ]): string;
    encodeFunctionData(functionFragment: "deployInstanceProxy", values: [
        string,
        string,
        BytesLike,
        BytesLike,
        BigNumberish,
        ThirdwebContract.ThirdwebInfoStruct
    ]): string;
    decodeFunctionResult(functionFragment: "deployInstance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deployInstanceProxy", data: BytesLike): Result;
    events: {
        "ContractDeployed(address,address,address)": EventFragment;
        "Paused(bool)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ContractDeployed"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Paused"): EventFragment;
}
declare type ContractDeployedEvent = TypedEvent<[
    string,
    string,
    string
], {
    deployer: string;
    publisher: string;
    deployedContract: string;
}>;
declare type ContractDeployedEventFilter = TypedEventFilter<ContractDeployedEvent>;
declare type PausedEvent = TypedEvent<[boolean], {
    isPaused: boolean;
}>;
declare type PausedEventFilter = TypedEventFilter<PausedEvent>;
interface IByocFactory extends BaseContract {
    contractName: string | "IByocFactory";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IByocFactoryInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        deployInstance(publisher: string, contractBytecode: BytesLike, constructorArgs: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        deployInstanceProxy(publisher: string, implementation: string, initializeData: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    deployInstance(publisher: string, contractBytecode: BytesLike, constructorArgs: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    deployInstanceProxy(publisher: string, implementation: string, initializeData: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        deployInstance(publisher: string, contractBytecode: BytesLike, constructorArgs: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: CallOverrides): Promise<string>;
        deployInstanceProxy(publisher: string, implementation: string, initializeData: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: CallOverrides): Promise<string>;
    };
    filters: {
        "ContractDeployed(address,address,address)"(deployer?: string | null, publisher?: string | null, deployedContract?: null): ContractDeployedEventFilter;
        ContractDeployed(deployer?: string | null, publisher?: string | null, deployedContract?: null): ContractDeployedEventFilter;
        "Paused(bool)"(isPaused?: null): PausedEventFilter;
        Paused(isPaused?: null): PausedEventFilter;
    };
    estimateGas: {
        deployInstance(publisher: string, contractBytecode: BytesLike, constructorArgs: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        deployInstanceProxy(publisher: string, implementation: string, initializeData: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        deployInstance(publisher: string, contractBytecode: BytesLike, constructorArgs: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        deployInstanceProxy(publisher: string, implementation: string, initializeData: BytesLike, salt: BytesLike, value: BigNumberish, thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}

export { ContractDeployedEvent, ContractDeployedEventFilter, IByocFactory, IByocFactoryInterface, PausedEvent, PausedEventFilter, ThirdwebContract };
