import { utils, BytesLike, BaseContract, Signer, CallOverrides, Overrides, ContractTransaction, BigNumber, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common';

interface ThirdwebContractInterface extends utils.Interface {
    contractName: string | "ThirdwebContract";
    functions: {
        "contractURI()": FunctionFragment;
        "getPublishMetadataUri()": FunctionFragment;
        "setThirdwebInfo((string,string))": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "contractURI", values?: undefined): string;
    encodeFunctionData(functionFragment: "getPublishMetadataUri", values?: undefined): string;
    encodeFunctionData(functionFragment: "setThirdwebInfo", values: [ThirdwebContract.ThirdwebInfoStruct]): string;
    decodeFunctionResult(functionFragment: "contractURI", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPublishMetadataUri", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setThirdwebInfo", data: BytesLike): Result;
    events: {};
}
declare namespace ThirdwebContract {
    type ThirdwebInfoStruct = {
        publishMetadataUri: string;
        contractURI: string;
    };
    type ThirdwebInfoStructOutput = [string, string] & {
        publishMetadataUri: string;
        contractURI: string;
    };
}
interface ThirdwebContract extends BaseContract {
    contractName: string | "ThirdwebContract";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: ThirdwebContractInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        contractURI(overrides?: CallOverrides): Promise<[string]>;
        getPublishMetadataUri(overrides?: CallOverrides): Promise<[string]>;
        setThirdwebInfo(_thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    contractURI(overrides?: CallOverrides): Promise<string>;
    getPublishMetadataUri(overrides?: CallOverrides): Promise<string>;
    setThirdwebInfo(_thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        contractURI(overrides?: CallOverrides): Promise<string>;
        getPublishMetadataUri(overrides?: CallOverrides): Promise<string>;
        setThirdwebInfo(_thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        contractURI(overrides?: CallOverrides): Promise<BigNumber>;
        getPublishMetadataUri(overrides?: CallOverrides): Promise<BigNumber>;
        setThirdwebInfo(_thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        contractURI(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPublishMetadataUri(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setThirdwebInfo(_thirdwebInfo: ThirdwebContract.ThirdwebInfoStruct, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}

export { ThirdwebContract, ThirdwebContractInterface };
